@@ -9,6 +9,11 @@ def install_node(version='16.x'):
     os.system("sudo bash /tmp/nodesource_setup.sh")
     print("Update nodesource success, please exec command `apt install nodejs -y` to install Node.js v{version}")
 
+def install_node_with_nvm(version='16'):
+    args = f"curl -o- https://raw.githubusercontent.com/nvm-sh/nvm/v0.39.3/install.sh | bash"
+    os.system(args)
+    os.system(f"nvm install {version}")
+    print("Install Node.js success, please exec command `nvm use {version}` to use Node.js v{version}")
 
 def install_neovim(version="0.8.0"):
     args = f"RUN wget https://github.com/neovim/neovim/releases/download/v{version}/nvim-linux64.deb && " \
