@@ -1,12 +1,23 @@
-from sparrow.path import rel_to_abs
+from sparrow.path import rel_to_abs, ls
 import pickle
 from typing import Union, List, Dict
 import shutil
+import os
 
 
-def rm(*files: str):
-    for file in files:
-        shutil.rmtree(file, ignore_errors=True)
+def rm(*file_pattern: str, rel=False):
+    """Remove files or directories.
+    Example:
+    --------
+        >>> rm("*.jpg", "*.png")
+        >>> rm("*.jpg", "*.png", rel=True)
+    """
+    path_list = ls(".", *file_pattern, relp=rel, concat="extend")
+    for file in path_list:
+        if os.path.isfile(file):
+            os.remove(file)
+        elif os.path.isdir(file):
+            shutil.rmtree(file, ignore_errors=True)
 
 def save(filename, file):
     with open(filename, "wb") as fw:
